CompressedEdwardsY

Struct CompressedEdwardsY 

pub struct CompressedEdwardsY(pub [u8; 32]);
In “Edwards y” / “Ed25519” format, the curve point \((x,y)\) is determined by the \(y\)-coordinate and the sign of \(x\).

The first 255 bits of a CompressedEdwardsY represent the \(y\)-coordinate. The high bit of the 32nd byte gives the sign of \(x\).

Tuple Fields

0: [u8; 32]

Implementations

Source

impl CompressedEdwardsY

pub const fn as_bytes(&self) -> &[u8; 32]

View this CompressedEdwardsY as an array of bytes.

pub const fn to_bytes(&self) -> [u8; 32]

Copy this CompressedEdwardsY to an array of bytes.

pub fn decompress(&self) -> Option<EdwardsPoint>

Attempt to decompress to an EdwardsPoint.

Returns None if the input is not the \(y\)-coordinate of a curve point.

Source

impl CompressedEdwardsY

pub fn from_slice(bytes: &[u8]) -> Result<CompressedEdwardsY, TryFromSliceError>

Construct a CompressedEdwardsY from a slice of bytes.

Errors

Returns TryFromSliceError if the input bytes slice does not have a length of 32.